qbsmgr
======

qbsmgr is a simplistic session manager for Qutebrowser.

It (ab)uses Qutebrowser's `--basedir` option to separate the different session's
data.


Dependencies
------------

 * POSIX-compliant `/bin/sh`
 * POSIX-compliant `cat`, `exec`, `id`, `printf`, `test`/`[` and `true`/`false`
 * `getent` from GNU Coreutils
 * `ln` from GNU Coreutils (or equivalent, with support for `-T`)
 * Qutebrowser

Further dependencies for `qbsmgr-menu`:

 * `dmenu`
 * `notify-send` from libnotify


Installation
------------

`qbsmgr` is a single POSIX sh script that can be installed to some place in
`$PATH` as is (or simply run from this project directory).

`qbsmgr-menu` is a single POSIX sh script that can be installed to some place in
`$PATH` as is (or simply run from this project directory). However, it expects
`qbsmgr` to be present in `$PATH`.

The manpages are typeset in Groff and can be installed to the system as is (or
simply be read in this project directory with `man ./qbsmgr.1` and `man
./qbsmgr-menu.1`, respectively).

The example XDG desktop entry file (`org.karui.qbsmgr.desktop`) can be installed
to `/usr/share/applications`. It will launch the `default` session (this will
fail if the session does not exist yet).

Packagers may be interested in [this example PKGBUILD][pkgbuild].


Usage examples
--------------

### qbsmgr

Sessions can be created with the `create` command:

    $ qbsmgr create my-session
    $ qbsmgr create another-session

The list of existing sessions can be displayed with `list`:

    $ qbsmgr list
    my-session
    another-session

A session can be started with `run`:

    $ qbsmgr run my-session

Note that active sessions are marked as such in `list`; one can also limit the
output to only active or only inactive sessions:

    $ qbsmgr list
    my-session [active]
    another-session

    $ qbsmgr list -s active
    my-session

    $ qbsmgr list -s inactive
    another-session

To delete a session, use `delete`:

    $ qbsmgr delete another-session
    $ qbsmgr list
    my-session [active]

The full documentation with an explanation of available options can be found in
the corresponding manpages.

### qbsmgr-menu

`qbsmgr-menu` is a simple wrapper around `dmenu` that presents all inactive
sessions in a menu and launches the selected session.


Rationale
---------

The functionality provided by this was previously implemented as a simpler
[wrapper script][localdir:qutebrowser] that overrode Qutebrowser's `-r` option
to have dwb-like sessions.

However, that script would simply create specified sessions if they did not
exist; consequently, typos would lead to a proliferation of unused sessions over
time, requiring occasional manual clean-up.

This project seeks to prevent that by providing a way of easily enumerating,
deleting and launching existing sessions.


[localdir:qutebrowser]: https://github.com/ayekat/localdir/blob/master/lib/dotfiles/wrappers/qutebrowser
[pkgbuild]: https://gitlab.com/ayekat/PKGBUILDs/-/blob/qbsmgr-git/PKGBUILD
